@@ -15,3 +15,8 @@ except ImportError:
         import ImageStat
     except ImportError:
         raise ImportError('ImageKit was unable to import the Python Imaging Library. Please confirm it`s installed and available on your current Python path.')
+
+try:
+    from cStringIO import StringIO
+except ImportError:
+    from StringIO import StringIO
